@@ -14,11 +14,42 @@ class FmpDataSource(DataSourceInterface):
         self.resolution = resolution
         self.stocks = {}
 
+    def get_historical_daily_prices(self, symbol: str, start_date: date, end_date: date = None):
+        """
+        Gets the historical prices of the given stock for the given interval period
+        Args:
+            symbol: Symbol of the stock/forex
+            start_date: Starting time of the interval of historical prices
+            end_date: Ending time of the interval of historical price. Default value is the time of the backtest
+        Returns: An array of the closing price of the stock for every day between the interval
+        """
+        if end_date is None:
+            end_date = self.timestamp.date()
+
+        if symbol not in self.stocks:
+            self._store_price_points(symbol, start_date, end_date)
+        else:
+            stock = self.stocks[symbol]
+
+            # This makes sure we're not querying price points we already have.
+            if stock.start_date is not None and stock.start_date > start_date:
+                uncached_start_date = start_date
+                uncached_end_date = stock.start_date
+                self._store_price_points(symbol, uncached_start_date, uncached_end_date)
+
+            if stock.end_date is not None and stock.end_date < end_date:
+                uncached_end_date = end_date
+                uncached_start_date = stock.end_date
+                self._store_price_points(symbol, uncached_start_date, uncached_end_date)
+
+        return [p for p in self.stocks[symbol].price_points.values()
+                if start_date <= datetime.strptime(p.date, "%Y-%m-%d").date() <= end_date]
+
     def get_price(self, symbol: str, timestamp: datetime = None, value: str = None) -> int:
         """
-        Gets the price of the stock at the current timestamp
+        Gets the price of the stock/forex at the current timestamp
         Args:
-            symbol: Symbol of the stock
+            symbol: Symbol of the stock/forex
             timestamp: Time of the data you want. If you want the current time of the backtest, leave empty
             value: Value of the stock you want (open, close, low, high, etc)
         Returns: The stock price at the given timestamp
@@ -124,6 +155,33 @@ class FmpDataSource(DataSourceInterface):
         response = self.request(url)
         return json.loads(response)
 
+    def get_income_statement_list(self) -> list:
+        """
+        Gets all the symbols with income statements available in FMP
+        Returns: A list (symbol) of all the symbols with available income statements
+        """
+        url = self.URL_BASE_FMP + "financial-statement-symbol-lists?apikey=" + self.token
+        response = self.request(url)
+        return json.loads(response)
+
+    def get_tradable_symbol_list(self) -> list:
+        """
+        Gets all the tradable symbols available in FMP
+        Returns: A list (symbol, name, price, exchange, exchangeShortName) of all tradable symbols
+        """
+        url = self.URL_BASE_FMP + "available-traded/list?apikey=" + self.token
+        response = self.request(url)
+        return json.loads(response)
+
+    def get_forex_currency_pairs_list(self) -> list:
+        """
+        Gets all the forex currency pairs available in FMP
+        Returns: A list (symbol, name, currency, stockExchange, exchangeShortName) of all available currency pairs
+        """
+        url = self.URL_BASE_FMP + "symbol/available-forex-currency-pairs?apikey=" + self.token
+        response = self.request(url)
+        return json.loads(response)
+
     def get_remaining_calls(self) -> int:
         """
         Gets the amount of remaining calls from the fmp datasource, this number comes directly from fmp and is not
@@ -188,6 +246,12 @@ class FmpDataSource(DataSourceInterface):
             url = self.URL_BASE_FMP + url_resolution + symbol + "?" + interval + "&apikey=" + self.token
             response = self.request(url)
 
+            if stock.start_date is None or stock.start_date > start_date:
+                stock.start_date = start_date
+
+            if stock.end_date is None or stock.end_date < current_end_date:
+                stock.end_date = current_end_date
+
             if response == "{ }":
                 break
             result = json.loads(response)
